@@ -20,4 +20,4 @@ class ErrorMs(Error):
         self.message = message
         self.headers = headers
         self.http_code = http_status_code
-        super().__init__(self.message)
+        super().__init__(self.errorCode)
