@@ -52,7 +52,7 @@ class ForkHttp(Fork):
         url_coll = {}
 
         # Validar si existen mas elementos
-        if len(url_pat.split(',')) > 1:
+        if len(url_pat.split(',')) > 0:
             for url in url_pat.split(','):
                 if len(url.split('@')) > 1:
                     URL_S = url.split('@')
@@ -104,6 +104,8 @@ class ForkHttp(Fork):
                         data.get('data', {}),
                         response
                     )
+                    if data_send is None:
+                        data_send = data.get('data', {})
                 except Exception as err:
                     self.logs.error(err)
 
@@ -117,7 +119,8 @@ class ForkHttp(Fork):
                     resp_rest = requests.post(
                         url_pet,
                         data=json.dumps(data_send),
-                        headers=headers
+                        headers=headers,
+                        timeout=60
                     )
                 elif act == Actions.DELETE:
                     resp_rest = requests.delete(url_pet, headers=headers)
@@ -191,6 +194,7 @@ class ForkHttp(Fork):
 
             else:
                 rp = resp_rest.json()
+
                 data['response'] = {}
                 data['response'].update({
                     "data": rp.get('data', {})
