@@ -132,22 +132,7 @@ class Microservices(BaseClass, ABC):
         if self.__FORKS is None:
             self.__APP = Worker(self.__TOPIC__)
         else:
-            self.logs.info(
-                'Se Inicia el servicio con soporte para bifurcaciones')
-
-            if not os.environ.get('REST_ENABLED', None) is None:
-                if os.environ.get('URL_ENDPOINT_SERVICES', None) is None:
-                    self.logs.error(
-                        "No se proporciono el valor para URL_ENDPOINT_SERVICES"
-                    )
-                    sys.exit(-1)
-                else:
-                    self.logs.info("Se inicia el soporte de Fork Http")
-                    self.__APP = ForkHttp(self.__TOPIC__)
-            else:
-                self.__APP = Fork(self.__TOPIC__)
-
-            self.___isForks = True
+            self.__fork_init()
 
         # Inicializar el redis
         self.initRedis()
@@ -177,6 +162,24 @@ class Microservices(BaseClass, ABC):
         if os.environ.get('REST_ENABLED', None):
             self.__loop_async(self.start())
 
+    def __fork_init(self):
+        self.logs.info(
+            'Se Inicia el servicio con soporte para bifurcaciones')
+
+        if not os.environ.get('REST_ENABLED', None) is None:
+            if os.environ.get('URL_ENDPOINT_SERVICES', None) is None:
+                self.logs.error(
+                    "No se proporciono el valor para URL_ENDPOINT_SERVICES"
+                )
+                sys.exit(-1)
+            else:
+                self.logs.info("Se inicia el soporte de Fork Http")
+                self.__APP = ForkHttp(self.__TOPIC__)
+        else:
+            self.__APP = Fork(self.__TOPIC__)
+
+        self.___isForks = True
+
     def __loop_async(self, fn):
         """
             Metodo para mandar llamar el ciclo del async
@@ -421,6 +424,12 @@ class Microservices(BaseClass, ABC):
         # Parametros solicitados
         paramsConf = []
 
+        # Contexto de la operacion
+        ctx = None
+
+        # Span
+        span = None
+
         # Recuperar el rootSpan
         # msg['metadata']['span'] if 'span' in msg['metadata'] else None
         rootSpan = None
@@ -584,8 +593,12 @@ class Microservices(BaseClass, ABC):
         if rootSpan is not None:
             rootSpan = self.___Tracer.extract(Format.TEXT_MAP, rootSpan)
 
-        span = self.___Tracer.start_span(operation_name=getattr(
-            mth, '__FUNC_NAME__'), references=child_of(rootSpan))
+        if rootSpan is None:
+            span = self.___Tracer.start_span(
+                operation_name=getattr(mth, '__FUNC_NAME__'))
+        else:
+            span = self.___Tracer.start_span(operation_name=getattr(
+                mth, '__FUNC_NAME__'), references=child_of(rootSpan))
 
         span.set_tag(ext_tags.HTTP_METHOD, msg['metadata']['method'])
 
@@ -596,9 +609,14 @@ class Microservices(BaseClass, ABC):
             # Configuracion de los forks
             if confForks is None:
                 self.__APP = Worker(self.__TOPIC__)
+                # Copiar el contexto de la ejucion
+                ctx = copy_context()
             else:
+                self.__fork_init()
                 # self.__APP = Fork(self.__TOPIC__)
                 self.__APP.confForks(confForks)
+                # Copiar el contexto de la ejucion
+                ctx = copy_context()
 
             # Indicar si es una bifurcacion
             msg['metadata']['bifurcacion'] = True if confForks else False
@@ -609,9 +627,6 @@ class Microservices(BaseClass, ABC):
                 "id_transaction": meta.get('id_transaction', uuid.uuid4())
             })
 
-            # Copiar el contexto de la ejucion
-            ctx = copy_context()
-
             # ejecutar el proceso
             RESP = ctx.run(self.__APP.process, span, msg, mth, paramsConf)
 
